@@ -62,7 +62,7 @@ class Table(BaseDialect):
     _how_to_quote_column = '"{}"'
     _column_setter = '{} AS {}'
     _sample_value_function = 'MAX({c})'
-    
+
     ENCODE=dict(zip(COLUMN_ENCODE, COLUMN_ENCODE))
 
     @property
@@ -89,7 +89,7 @@ class Table(BaseDialect):
 
     def get_create_table_as(self, select, embed_select=True, filter_fn=None, suffix=''):
         return Template("""
-            CREATE TABLE IF NOT EXISTS {{ t.full_table_name(quoted=True, with_prefix=True, suffix=suffix) }}
+            CREATE TABLE {{ t.full_table_name(quoted=True, with_prefix=True, suffix=suffix) }}
             {%- for property in t.properties %}
             {{ property }}
             {%- endfor %} AS
